Module blocking

Module blocking 

functions which may be blocked by network-roundtrips

When the separate_blocking feature is enabled, functions whose column Round-Trips? value in ODPI-C Function Round-Trips is Yes or Maybe are in this module.

There are no functions when the feature is disabled.