dpiConn_close

Function dpiConn_close 

pub unsafe extern "C" fn dpiConn_close(
    conn: *mut dpiConn,
    mode: dpiConnCloseMode,
    tag: *const c_char,
    tagLength: u32,
) -> c_int
Closes the connection and makes it unusable for further activity. Any open statements and LOBs associated with the connection will also be closed and made unusable for further activity.

The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.