dpiConn_create

Function dpiConn_create 

pub unsafe extern "C" fn dpiConn_create(
    context: *const dpiContext,
    userName: *const c_char,
    userNameLength: u32,
    password: *const c_char,
    passwordLength: u32,
    connectString: *const c_char,
    connectStringLength: u32,
    commonParams: *const dpiCommonCreateParams,
    createParams: *mut dpiConnCreateParams,
    conn: *mut *mut dpiConn,
) -> c_int
Creates a standalone connection to a database or acquires a connection from a session pool and returns a reference to the connection.

The function returns DPI_SUCCESS for success and DPI_FAILURE for failure. If a failure occurs, the errorInfo structure is filled in with error information.