pub unsafe extern "C" fn dpiConn_getDbDomain(
conn: *mut dpiConn,
value: *mut *const c_char,
valueLength: *mut u32,
) -> c_intExpand description
Returns the Oracle Database Domain name associated with the connection.
This is the same value returned by the SQL expression
SELECT value FROM V$PARAMETER WHERE NAME = 'db_domain'.
This function returns DPI_SUCCESS for success and DPI_FAILURE for failure.