dpiConn_getEncodingInfo

Function dpiConn_getEncodingInfo 

pub unsafe extern "C" fn dpiConn_getEncodingInfo(
    conn: *mut dpiConn,
    info: *mut dpiEncodingInfo,
) -> c_int
Returns the encoding information used by the connection. This will be equivalent to the values passed when the standalone connection or session pool was created, or the values retrieved from the environment variables NLS_LANG and NLS_NCHAR.

The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.