dpiConn_getServiceName

Function dpiConn_getServiceName 

pub unsafe extern "C" fn dpiConn_getServiceName(
    conn: *mut dpiConn,
    value: *mut *const c_char,
    valueLength: *mut u32,
) -> c_int
Returns the Oracle Database service name associated with the connection. This is the same value returned by the SQL expression SELECT SYS_CONTEXT('USERENV', 'SERVICE_NAME') FROM DUAL.

This function returns DPI_SCCUESS for success and DPI_FAILURE for failure.