dpiConn_ping

Function dpiConn_ping 

pub unsafe extern "C" fn dpiConn_ping(conn: *mut dpiConn) -> c_int
Pings the database to determine if a connection is usable.

This function does the local, light-weight checks of dpiConn_getIsHealthy() and additionally performs a round-trip to the database if the local checks are successful.

The session pool internally may perform this check before returning a connection to the application. This depends on the value of DPI_DEFAULT_PING_INTERVAL and when the connection was returned to the pool.

The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.

If DPI_FAILURE is returned, the application should close the connection.