dpiConn_setClientIdentifier

Function dpiConn_setClientIdentifier 

pub unsafe extern "C" fn dpiConn_setClientIdentifier(
    conn: *mut dpiConn,
    value: *const c_char,
    valueLength: u32,
) -> c_int
Sets the client identifier attribute on the connection. This is one of the end-to-end tracing attributes that can be tracked in database views, shown in audit trails and seen in tools such as Enterprise Manager.

The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.