pub unsafe extern "C" fn dpiConn_setCurrentSchema(
conn: *mut dpiConn,
value: *const c_char,
valueLength: u32,
) -> c_intExpand description
Sets the current schema to be used on the connection. This has the same effect as the SQL statement ALTER SESSION SET CURRENT_SCHEMA. The value be changed when the next call requiring a round trip to the server is performed. If the new schema name does not exist, the same error is returned as when the alter session statement is executed. The new schema name is placed before database objects in statement that you execute that do not already have a schema.
The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.