pub unsafe extern "C" fn dpiConn_shutdownDatabase(
conn: *mut dpiConn,
mode: dpiShutdownMode,
) -> c_intExpand description
Shuts down the database. This function must be called twice for the database to be shut down successfully. After calling this function the first time, the SQL statements “alter database close normal” and “alter database dismount” must be executed. Once that is complete this function should be called again with the mode DPI_MODE_SHUTDOWN_FINAL in order to complete the orderly shutdown of the database.
The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.