dpiContext_createWithParams

Function dpiContext_createWithParams 

pub unsafe extern "C" fn dpiContext_createWithParams(
    majorVersion: c_uint,
    minorVersion: c_uint,
    params: *mut dpiContextCreateParams,
    context: *mut *mut dpiContext,
    errorInfo: *mut dpiErrorInfo,
) -> c_int
Creates a new context for interaction with the library. This is the first function that must be called and it must have completed successfully before any other functions can be called, including in other threads.

The function returns DPI_SUCCESS for success and DPI_FAILURE for failure. If a failure occurs, the errorInfo structure is filled in with error information.