pub unsafe extern "C" fn dpiData_getIntervalDS(
data: *mut dpiData,
) -> *mut dpiIntervalDSExpand description
Returns a pointer to the value of the data when the native type is DPI_NATIVE_TYPE_INTERVAL_DS.
pub unsafe extern "C" fn dpiData_getIntervalDS(
data: *mut dpiData,
) -> *mut dpiIntervalDSReturns a pointer to the value of the data when the native type is DPI_NATIVE_TYPE_INTERVAL_DS.