pub unsafe extern "C" fn dpiData_getJsonArray(
data: *mut dpiData,
) -> *mut dpiJsonArrayExpand description
Returns the value of the data when the native type is DPI_NATIVE_TYPE_JSON_ARRAY.
pub unsafe extern "C" fn dpiData_getJsonArray(
data: *mut dpiData,
) -> *mut dpiJsonArrayReturns the value of the data when the native type is DPI_NATIVE_TYPE_JSON_ARRAY.