pub unsafe extern "C" fn dpiData_getJsonObject(
data: *mut dpiData,
) -> *mut dpiJsonObjectExpand description
Returns the value of the data when the native type is DPI_NATIVE_TYPE_JSON_OBJECT.
pub unsafe extern "C" fn dpiData_getJsonObject(
data: *mut dpiData,
) -> *mut dpiJsonObjectReturns the value of the data when the native type is DPI_NATIVE_TYPE_JSON_OBJECT.