pub unsafe extern "C" fn dpiData_getTimestamp(
data: *mut dpiData,
) -> *mut dpiTimestampExpand description
Returns a pointer to the value of the data when the native type is DPI_NATIVE_TYPE_TIMESTAMP.
pub unsafe extern "C" fn dpiData_getTimestamp(
data: *mut dpiData,
) -> *mut dpiTimestampReturns a pointer to the value of the data when the native type is DPI_NATIVE_TYPE_TIMESTAMP.