dpiData_setBytes

Function dpiData_setBytes 

pub unsafe extern "C" fn dpiData_setBytes(
    data: *mut dpiData,
    ptr: *mut c_char,
    length: u32,
)
Sets the value of the data when the native type is DPI_NATIVE_TYPE_BYTES. Do not use this function when setting data for variables. Instead, use the function dpiVar_setFromBytes().