dpiData_setLOB

Function dpiData_setLOB 

pub unsafe extern "C" fn dpiData_setLOB(
    data: *mut dpiData,
    lob: *mut dpiLob,
)
Sets the value of the data when the native type is DPI_NATIVE_TYPE_LOB. Do not use this function when setting data for variables. Instead, use the function dpiVar_setFromLob().