dpiData_setObject

Function dpiData_setObject 

pub unsafe extern "C" fn dpiData_setObject(
    data: *mut dpiData,
    obj: *mut dpiObject,
)
Sets the value of the data when the native type is DPI_NATIVE_TYPE_OBJECT. Do not use this function when setting data for variables. Instead, use the function dpiVar_setFromObject().