dpiData_setStmt

Function dpiData_setStmt 

pub unsafe extern "C" fn dpiData_setStmt(
    data: *mut dpiData,
    stmt: *mut dpiStmt,
)
Sets the value of the data when the native type is DPI_NATIVE_TYPE_STMT. Do not use this function when setting data for variables. Instead, use the function dpiVar_setFromStmt().