pub unsafe extern "C" fn dpiDeqOptions_setCorrelation(
options: *mut dpiDeqOptions,
value: *const c_char,
valueLength: u32,
) -> c_intExpand description
Sets the correlation of the message to be dequeued. Special pattern matching characters such as the percent sign (%) and the underscore (_) can be used. If multiple messages satisfy the pattern, the order of dequeuing is undetermined.
The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.