pub unsafe extern "C" fn dpiLob_writeBytes(
lob: *mut dpiLob,
offset: u64,
value: *const c_char,
valueLength: u64,
) -> c_intExpand description
Write data to the LOB at the specified offset using the provided buffer as
the source. If multiple calls to this function are planned, the LOB should
first be opened using the function dpiLob_openResource().
The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.
WARNING: for historical reasons, Oracle stores CLOBs and NCLOBs using the UTF-16 encoding, regardless of what encoding is otherwise in use by the database. The number of characters, however, is defined by the number of UCS-2 codepoints. For this reason, if a character requires more than one UCS-2 codepoint, care must be taken to account for them in the offset parameter.