pub unsafe extern "C" fn dpiMsgProps_addRef(
props: *mut dpiMsgProps,
) -> c_intExpand description
Adds a reference to the message properties. This is intended for situations where a reference to the message properties needs to be maintained independently of the reference returned when the handle was created.
The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.