dpiMsgProps_getExceptionQ

Function dpiMsgProps_getExceptionQ 

pub unsafe extern "C" fn dpiMsgProps_getExceptionQ(
    props: *mut dpiMsgProps,
    value: *mut *const c_char,
    valueLength: *mut u32,
) -> c_int
Returns the name of the queue to which the message is moved if it cannot be processed successfully. See function dpiMsgProps_setExceptionQ() for more information.

The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.