dpiMsgProps_getPayload

Function dpiMsgProps_getPayload 

pub unsafe extern "C" fn dpiMsgProps_getPayload(
    props: *mut dpiMsgProps,
    obj: *mut *mut dpiObject,
    value: *mut *const c_char,
    valueLength: *mut u32,
) -> c_int
Returns the payload associated with the message properties. The payload can either be an object or an arbitrary series of bytes and is available after a call to dpiQueue_deqOne() or dpiQueue_deqMany().

The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.