pub unsafe extern "C" fn dpiMsgProps_getPayloadJson(
props: *mut dpiMsgProps,
json: *mut *mut dpiJson,
) -> c_intExpand description
Returns the payload associated with the message properties, The payload
must be a JSON object and is available after the call to
dpiQueue_deqOne() or dpiQueue_deqMany(); otherwise, the
value NULL will be returned.
The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.