dpiMsgProps_release

Function dpiMsgProps_release 

pub unsafe extern "C" fn dpiMsgProps_release(
    props: *mut dpiMsgProps,
) -> c_int
Releases a reference to the message properties. A count of the references to the message properties is maintained and when this count reaches zero, the memory associated with the properties is freed.

The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.