dpiMsgProps_setCorrelation

Function dpiMsgProps_setCorrelation 

pub unsafe extern "C" fn dpiMsgProps_setCorrelation(
    props: *mut dpiMsgProps,
    value: *const c_char,
    valueLength: u32,
) -> c_int
Sets the correlation of the message to be dequeued. Special pattern matching characters such as the percent sign (%) and the underscore (_) can be used. If multiple messages satisfy the pattern, the order of dequeuing is undetermined.

The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.