dpiMsgProps_setDelay

Function dpiMsgProps_setDelay 

pub unsafe extern "C" fn dpiMsgProps_setDelay(
    props: *mut dpiMsgProps,
    value: i32,
) -> c_int
Sets the number of seconds to delay the message before it can be dequeued. Messages enqueued with a delay are put into the DPI_MSG_STATE_WAITING state. When the delay expires the message is put into the DPI_MSG_STATE_READY state. Dequeuing directly by message id overrides this delay specification. Note that delay processing requires the queue monitor to be started.

The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.