pub unsafe extern "C" fn dpiMsgProps_setExceptionQ(
props: *mut dpiMsgProps,
value: *const c_char,
valueLength: u32,
) -> c_intExpand description
Sets the name of the queue to which the message is moved if it cannot be processed successfully. Messages are moved if the number of unsuccessful dequeue attempts has reached the maximum allowed number or if the message has expired. All messages in the exception queue are in the DPI_MSG_STATE_EXPIRED state.
The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.