pub unsafe extern "C" fn dpiMsgProps_setExpiration(
props: *mut dpiMsgProps,
value: i32,
) -> c_intExpand description
Sets the number of seconds the message is available to be dequeued. This value is an offset from the delay. Expiration processing requires the queue monitor to be running. Until this time elapses, the messages are in the queue in the state DPI_MSG_STATE_READY. After this time elapses messages are moved to the exception queue in the DPI_MSG_STATE_EXPIRED state.
The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.