dpiObjectType_addRef

Function dpiObjectType_addRef 

pub unsafe extern "C" fn dpiObjectType_addRef(
    objType: *mut dpiObjectType,
) -> c_int
Adds a reference to the object type. This is intended for situations where a reference to the object type needs to be maintained independently of the reference returned when the object type was created.

The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.