dpiObjectType_release

Function dpiObjectType_release 

pub unsafe extern "C" fn dpiObjectType_release(
    objType: *mut dpiObjectType,
) -> c_int
Releases a reference to the object type. A count of the references to the object type is maintained and when this count reaches zero, the memory associated with the object type is freed.

The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.