dpiObject_addRef

Function dpiObject_addRef 

pub unsafe extern "C" fn dpiObject_addRef(
    obj: *mut dpiObject,
) -> c_int
Adds a reference to the object. This is intended for situations where a reference to the object needs to be maintained independently of the reference returned when the object was created.

The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.