dpiObject_copy

Function dpiObject_copy 

pub unsafe extern "C" fn dpiObject_copy(
    obj: *mut dpiObject,
    copiedObj: *mut *mut dpiObject,
) -> c_int
Creates an independent copy of an object and returns a reference to the newly created object. This reference should be released as soon as it is no longer needed.

The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.