dpiObject_release

Function dpiObject_release 

pub unsafe extern "C" fn dpiObject_release(
    obj: *mut dpiObject,
) -> c_int
Releases a reference to the object. A count of the references to the object is maintained and when this count reaches zero, the memory associated with the object is freed.

The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.