dpiPool_addRef

Function dpiPool_addRef 

pub unsafe extern "C" fn dpiPool_addRef(pool: *mut dpiPool) -> c_int
Adds a reference to the pool. This is intended for situations where a reference to the pool needs to be maintained independently of the reference returned when the pool was created.

The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.