dpiPool_getEncodingInfo

Function dpiPool_getEncodingInfo 

pub unsafe extern "C" fn dpiPool_getEncodingInfo(
    pool: *mut dpiPool,
    info: *mut dpiEncodingInfo,
) -> c_int
Returns the encoding information used by the pool. This will be equivalent to the values passed when the pool was created, or the values retrieved from the environment variables NLS_LANG and NLS_NCHAR.

The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.