dpiPool_getWaitTimeout

Function dpiPool_getWaitTimeout 

pub unsafe extern "C" fn dpiPool_getWaitTimeout(
    pool: *mut dpiPool,
    value: *mut u32,
) -> c_int
Returns the amount of time (in milliseconds) that the caller will wait for a session to become available in the pool before returning an error.

The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.