dpiPool_release

Function dpiPool_release 

pub unsafe extern "C" fn dpiPool_release(pool: *mut dpiPool) -> c_int
Releases a reference to the pool. A count of the references to the pool is maintained and when this count reaches zero, the memory associated with the pool is freed and the session pool is closed if that has not already taken place using the function dpiPool_close().

The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.