dpiPool_setAccessToken

Function dpiPool_setAccessToken 

pub unsafe extern "C" fn dpiPool_setAccessToken(
    pool: *mut dpiPool,
    params: *mut dpiAccessToken,
) -> c_int
The function is used to manually set the token and private key for a session pool. After pool creation it can be used to periodically reset the token and private key to avoid the need for the pool token callback function [dpiPoolCreateParams.accessTokenCallback] to be called during pool growth.

This function may also be useful for testing. By setting an expired token and key the subsequent pool callback function behavior can be seen without waiting for normal token expiry.

The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.