pub unsafe extern "C" fn dpiPool_setMaxLifetimeSession(
pool: *mut dpiPool,
value: u32,
) -> c_intExpand description
Sets the maximum lifetime a pooled session may exist, in seconds. Sessions in use will not be closed. They become candidates for termination only when they are released back to the pool and have existed for longer then the specified value. Note that termination only occurs when the pool is accessed. The value 0 means that there is no maximum length of time that a pooled session may exist.
The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.