pub unsafe extern "C" fn dpiPool_setPingInterval(
pool: *mut dpiPool,
value: c_int,
) -> c_intExpand description
Sets the ping interval duration (in seconds) which is used to to check for healthiness of sessions. If this time has passed since the last time the session was checked out a ping will be performed. A negative value will disable this check.
The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.