pub unsafe extern "C" fn dpiQueue_release(
queue: *mut dpiQueue,
) -> c_intExpand description
Releases a reference to the queue. A count of the references to the queue is maintained and when this count reaches zero, the memory associated with the queue is freed.
The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.