pub unsafe extern "C" fn dpiRowid_release(
subscr: *mut dpiRowid,
) -> c_intExpand description
Releases a reference to the rowid. A count of the references to the rowid is maintained and when this count reaches zero, the memory associated with the rowid is freed.
The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.