dpiSodaColl_insertMany

Function dpiSodaColl_insertMany 

pub unsafe extern "C" fn dpiSodaColl_insertMany(
    coll: *mut dpiSodaColl,
    numDocs: u32,
    docs: *mut *mut dpiSodaDoc,
    flags: u32,
    insertedDocs: *mut *mut dpiSodaDoc,
) -> c_int
Inserts multiple documents into the collection and optionally returns result documents containing information about the newly inserted documents.

The function returns DPI_SUCCESS for success and DPI_FAILURE for failure. On failure the offset attribute in the dpiErrorInfo structure will contain the index into the SODA document handles array where the error took place.

NOTE: this function requires Oracle Client 18.5 or higher in addition to the usual SODA requirements and is currently available only as a preview.