dpiSodaColl_insertManyWithOptions

Function dpiSodaColl_insertManyWithOptions 

pub unsafe extern "C" fn dpiSodaColl_insertManyWithOptions(
    coll: *mut dpiSodaColl,
    numDocs: u32,
    docs: *mut *mut dpiSodaDoc,
    options: *mut dpiSodaOperOptions,
    flags: u32,
    insertedDocs: *mut *mut dpiSodaDoc,
) -> c_int
Inserts multiple documents into the collection and optionally returns result documents containing information about the newly inserted documents. In addition, options can be supplied to modify how the documents are inserted or returned.

This function requires Oracle Client 21.3 or higher to be used in addition to the normal SODA requirements (also available in Oracle Client 19 from 19.11).

The function returns DPI_SUCCESS for success and DPI_FAILURE for failure. On failure the offset attribute in the dpiErrorInfo structure will contain the index into the SODA document handles array where the error took place.