pub unsafe extern "C" fn dpiSodaColl_insertOneWithOptions(
coll: *mut dpiSodaColl,
doc: *mut dpiSodaDoc,
options: *mut dpiSodaOperOptions,
flags: u32,
insertedDoc: *mut *mut dpiSodaDoc,
) -> c_intExpand description
Inserts a document into the collection and optionally returns it. In addition, options can be supplied to modify how the document is inserted or returned.
This method requires Oracle Client 21.3 or higher to be used in addition to the normal SODA requirements (also available in Oracle Client 19 from 19.11).
The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.