pub unsafe extern "C" fn dpiSodaDoc_getKey(
doc: *mut dpiSodaDoc,
value: *mut *const c_char,
valueLength: *mut u32,
) -> c_intExpand description
Returns the key that uniquely identifies the document in the collection.
This value will be empty if no key was supplied when the document was
created using dpiSodaDb_createDocument().
The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.