dpiSodaDoc_getLastModified

Function dpiSodaDoc_getLastModified 

pub unsafe extern "C" fn dpiSodaDoc_getLastModified(
    doc: *mut dpiSodaDoc,
    value: *mut *const c_char,
    valueLength: *mut u32,
) -> c_int
Returns the timestamp when the document was last modified, as a string, in ISO format. This value will be empty if the metadata used to create the collection in which the document is found does not support the storage of this attribute, or if the document was created using dpiSodaDb_createDocument().

The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.