pub unsafe extern "C" fn dpiStmt_bindByPos(
stmt: *mut dpiStmt,
pos: u32,
var: *mut dpiVar,
) -> c_intExpand description
Binds a variable to a placeholder in the statement by position. A reference to the variable is retained by the library and is released when the statement itself is released or a new variable is bound to the same position.
The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.