dpiStmt_bindValueByPos

Function dpiStmt_bindValueByPos 

pub unsafe extern "C" fn dpiStmt_bindValueByPos(
    stmt: *mut dpiStmt,
    pos: u32,
    nativeTypeNum: dpiNativeTypeNum,
    data: *mut dpiData,
) -> c_int
Binds a value to a placeholder in the statement without the need to create a variable directly. One is created implicitly and released when the statement is released or a new value is bound to the same position.

The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.