dpiStmt_define

Function dpiStmt_define 

pub unsafe extern "C" fn dpiStmt_define(
    stmt: *mut dpiStmt,
    pos: u32,
    var: *mut dpiVar,
) -> c_int
Defines the variable that will be used to fetch rows from the statement. A reference to the variable will be retained until the next define is performed on the same position or the statement is closed.

The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.