dpiStmt_deleteFromCache

Function dpiStmt_deleteFromCache 

pub unsafe extern "C" fn dpiStmt_deleteFromCache(
    stmt: *mut dpiStmt,
) -> c_int
Excludes the associated SQL statement from the statement cache. If the SQL statement was not already in the cache, it will not be added. This function can be called before or after the statment is executed.

The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.