dpiStmt_fetch

Function dpiStmt_fetch 

pub unsafe extern "C" fn dpiStmt_fetch(
    stmt: *mut dpiStmt,
    found: *mut c_int,
    bufferRowIndex: *mut u32,
) -> c_int
Fetches a single row from the buffers defined for the query. If no row is available in the buffers, an internal fetch takes place to populate them, if rows are available. The number of rows fetched into the internal buffers can be set by calling dpiStmt_setFetchArraySize(). If the statement does not refer to a query an error is returned. All columns that have not been defined prior to this call are implicitly defined using the metadata made available when the statement was executed.

The function dpiStmt_fetchRows() should be used instead of this function if it is important to control when the internal fetch (and round-trip to the database) takes place.

The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.