dpiStmt_getBatchErrorCount

Function dpiStmt_getBatchErrorCount 

pub unsafe extern "C" fn dpiStmt_getBatchErrorCount(
    stmt: *mut dpiStmt,
    count: *mut u32,
) -> c_int
Returns the number of batch errors that took place during the last execution with batch mode enabled. Batch errors are only available when both the client and the server are at 12.1.

The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.