dpiStmt_getBindCount

Function dpiStmt_getBindCount 

pub unsafe extern "C" fn dpiStmt_getBindCount(
    stmt: *mut dpiStmt,
    count: *mut u32,
) -> c_int
Returns the number of bind variables in the prepared statement. In SQL statements this is the total number of bind variables whereas in PL/SQL statements this is the count of the unique bind variables.

The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.