pub unsafe extern "C" fn dpiStmt_getPrefetchRows(
stmt: *mut dpiStmt,
numRows: *mut u32,
) -> c_intExpand description
Gets the number of rows that will be prefetched by the Oracle Client library when a query is executed.
The value may be changed by calling dpiStmt_setPrefetchRows().
The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.