dpiStmt_getQueryValue

Function dpiStmt_getQueryValue 

pub unsafe extern "C" fn dpiStmt_getQueryValue(
    stmt: *mut dpiStmt,
    pos: u32,
    nativeTypeNum: *mut dpiNativeTypeNum,
    data: *mut *mut dpiData,
) -> c_int
Returns the value of the column at the given position for the currently fetched row, without needing to provide a variable. If the data type of the column needs to be overridden, the function dpiStmt_defineValue() can be called to specify a different type after executing the statement but before fetching any data.

This function should only be called after a call to the function dpiStmt_fetch() has succeeded and indicated that a row is available.

The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.