dpiStmt_getRowCount

Function dpiStmt_getRowCount 

pub unsafe extern "C" fn dpiStmt_getRowCount(
    stmt: *mut dpiStmt,
    count: *mut u64,
) -> c_int
Returns the number of rows affected by the last DML statement that was executed, the number of rows currently fetched from a query, or the number of successful executions of a PL/SQL block. In all other cases 0 is returned.

The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.