pub unsafe extern "C" fn dpiStmt_setFetchArraySize(
stmt: *mut dpiStmt,
arraySize: u32,
) -> c_intExpand description
Sets the array size used for performing fetches. All variables defined for fetching must have this many (or more) elements allocated for them. The higher this value is the less network round trips are required to fetch rows from the database but more memory is also required. A value of zero will reset the array size to the default value of DPI_DEFAULT_FETCH_ARRAY_SIZE.
The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.