dpiVar_getReturnedData

Function dpiVar_getReturnedData 

pub unsafe extern "C" fn dpiVar_getReturnedData(
    var: *mut dpiVar,
    pos: u32,
    numElements: *mut u32,
    data: *mut *mut dpiData,
) -> c_int
Returns a pointer to an array of dpiData structures used for transferring data to and from the database. These structures are allocated by the variable itself when a DML returning statement is executed and the variable is bound.

The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.