dpiVar_setFromBytes

Function dpiVar_setFromBytes 

pub unsafe extern "C" fn dpiVar_setFromBytes(
    var: *mut dpiVar,
    pos: u32,
    value: *const c_char,
    valueLength: u32,
) -> c_int
Sets the variable value to the specified byte string. In the case of the variable’s Oracle type being DPI_ORACLE_TYPE_NUMBER, the byte string is converted to an Oracle number during the call to this function.

The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.