#[repr(C)]pub struct dpiAnnotation {
pub key: *const c_char,
pub keyLength: u32,
pub value: *const c_char,
pub valueLength: u32,
}Expand description
This structure is part of the structure dpiDataTypeInfo
and provides information about annotations
associated with columns that are fetched from the database. Annotations are
only available with Oracle Database 23ai (or later). Oracle Client libraries
must also be 23.1 (or later).
Fields
key: *const c_charSpecifies the annoation key.
keyLength: u32Specifies the length of the annotation key, in bytes.
value: *const c_charSpecifies the annoation value.
valueLength: u32Specifies the length of the annotation value, in bytes.