dpiBytes

Struct dpiBytes 

#[repr(C)]
pub struct dpiBytes { pub ptr: *mut c_char, pub length: u32, pub encoding: *const c_char, }
This structure is used for passing byte strings to and from the database in the structure dpiData.

Fields

ptr: *mut c_char

Specifies the pointer to the memory allocated by ODPI-C for the variable. For strings, data written to this memory should be in the encoding appropriate to the type of data being transferred. When data is transferred from the database it will be in the correct encoding already.

length: u32

Specifies the length of the byte string, in bytes.

encoding: *const c_char

Specifies the encoding for character data. This value is populated when data is transferred from the database. It is ignored when data is being transferred to the database.