dpiJson

Struct dpiJson 

#[repr(C)]
pub struct dpiJson { /* private fields */ }
JSON handles are used to represent JSON values stored in the database. They are only available from Oracle Client and Database 20 and higher. They cannot be created directly but are created implicitly when a variable of type DPI_ORACLE_TYPE_JSON is created. They are destroyed when the last reference is released by a call to the function dpiJson_release().