dpiJsonNode

Struct dpiJsonNode 

#[repr(C)]
pub struct dpiJsonNode { pub oracleTypeNum: dpiOracleTypeNum, pub nativeTypeNum: dpiNativeTypeNum, pub value: *mut dpiDataBuffer, }
This structure is used for passing JSON node data to and from the database in the structure dpiData. Nodes can consist of scalar values, objects, or arrays.

Fields

oracleTypeNum: dpiOracleTypeNum

The Oracle type of the data that is stored in the node. It will be one of the values from the enumeration dpiOracleTypeNum.

nativeTypeNum: dpiNativeTypeNum

The native type of the data that is stored in the node. It will be one of the values from the enumeration dpiNativeTypeNum.

value: *mut dpiDataBuffer

The value that is stored in the node. It is a union of type dpiDataBuffer.