#[repr(C)]pub struct dpiJsonObject {
pub numFields: u32,
pub fieldNames: *mut *mut c_char,
pub fieldNameLengths: *mut u32,
pub fields: *mut dpiJsonNode,
pub fieldValues: *mut dpiDataBuffer,
}Expand description
This structure is used for passing JSON objects to and from the database.
Fields
numFields: u32Specifies the number of fields that are found in the JSON object. This also identifies the number of elements in each of the remaining arrays.
fieldNames: *mut *mut c_charSpecifies an array of field names that are found in the JSON object. Each
element is a byte string encoded in UTF-8. The length of each byte string
is found in the [dpiJsonObject.fieldNameLengths] member.
fieldNameLengths: *mut u32Specifies an array of lengths for the names of the fields found in the JSON object.
fields: *mut dpiJsonNodeSpecifies an array of JSON nodes that are the values of the fields found in
the JSON object. Each of these is a structure of type
dpiJsonNode.
fieldValues: *mut dpiDataBufferSpecifies an array of buffers that contain the data for the values of the
fields found in the JSON object. This member should not be used directly.
Instead, the [dpiJsonNode.value] member of the corresponding node
in the member [dpiJsonObject.fields] should be used.