dpiLob

Struct dpiLob 

#[repr(C)]
pub struct dpiLob { /* private fields */ }
LOB handles are used to represent large objects (CLOB, BLOB, NCLOB, BFILE). Both persistent and temporary large objects can be represented. LOB handles can be created by calling the function dpiConn_newTempLob() or are created implicitly when a variable of type DPI_ORACLE_TYPE_CLOB, DPI_ORACLE_TYPE_NCLOB, DPI_ORACLE_TYPE_BLOB or DPI_ORACLE_TYPE_BFILE is created and are destroyed when the last reference is released by calling the function dpiLob_release(). They are used for reading and writing data to the database in smaller pieces than is contained in the large object.