#[repr(C)]pub struct dpiObject { /* private fields */ }Expand description
Object handles are used to represent instances of the types created by the SQL
command CREATE OR REPLACE TYPE. They are created by calling the function
dpiObjectType_createObject() or calling the function
dpiObject_copy() or implicitly by creating a variable of the type
DPI_ORACLE_TYPE_OBJECT. The are destroyed when the last reference is released
by calling the function dpiObject_release().