#[repr(C)]pub struct dpiObjectAttrInfo {
pub name: *const c_char,
pub nameLength: u32,
pub typeInfo: dpiDataTypeInfo,
}Expand description
This structure is used for passing information about an object type from ODPI-C.
It is used by the function dpiObjectAttr_getInfo().
Fields
name: *const c_charSpecifies the name of the attribute, as a byte string in the encoding used for CHAR data.
nameLength: u32Specifies the length of the [dpiObjectAttrInfo.name] member, in
bytes.
typeInfo: dpiDataTypeInfoSpecifies the type of data of the attribute. It is a structure of type
dpiDataTypeInfo.