#[repr(C)]pub struct dpiObjectTypeInfo {
pub schema: *const c_char,
pub schemaLength: u32,
pub name: *const c_char,
pub nameLength: u32,
pub isCollection: c_int,
pub elementTypeInfo: dpiDataTypeInfo,
pub numAttributes: u16,
pub packageName: *const c_char,
pub packageNameLength: u32,
}Expand description
This structure is used for passing information about an object type from ODPI-C.
It is used by the function dpiObjectType_getInfo().
Fields
schema: *const c_charSpecifies the schema which owns the object type, as a byte string in the encoding used for CHAR data.
schemaLength: u32Specifies the length of the [dpiObjectTypeInfo.schema] member, in
bytes.
name: *const c_charSpecifies the name of the object type, as a byte string in the encoding used for CHAR data.
nameLength: u32Specifies the length of the [dpiObjectTypeInfo.name] member, in
bytes.
isCollection: c_intSpecifies if the object type is a collection (1) or not (0).
elementTypeInfo: dpiDataTypeInfoSpecifies the type of data of the elements in the collection. It is a
structure of type dpiDataTypeInfo which is only
valid if the object type is a collection.
numAttributes: u16Specifies the number of attributes that the object type has.
packageName: *const c_charSpecifies the name of the name of the package for a PL/SQL type, as a byte string in the encoding used for CHAR data. If the type is not a PL/SQL type, this value is NULL.
packageNameLength: u32Specifies the length of the [dpiObjectTypeInfo.packageName] member,
in bytes.