#[repr(C)]pub struct dpiQueryInfo {
pub name: *const c_char,
pub nameLength: u32,
pub typeInfo: dpiDataTypeInfo,
pub nullOk: c_int,
}Expand description
This structure is used for passing query metadata from ODPI-C. It is populated
by the function dpiStmt_getQueryInfo(). All values remain valid as long
as a reference is held to the statement and the statement is not re-executed or
closed.
Fields
name: *const c_charSpecifies the name of the column which is being queried, as a byte string in the encoding used for CHAR data.
nameLength: u32Specifies the length of the [dpiQueryInfo.name] member, in bytes.
typeInfo: dpiDataTypeInfoSpecifies the type of data of the column that is being queried. It is a
structure of type dpiDataTypeInfo.
nullOk: c_intSpecifies if the data that is being queried may return null values (1) or not (0).