#[repr(C)]pub struct dpiQueue { /* private fields */ }Expand description
Queue handles are used to represent Advanced Queueing (AQ) queues. They are
created by calling the function dpiConn_newQueue() and are destroyed
when the last reference is released by calling the function
dpiQueue_release().