#[repr(C)]pub struct dpiRowid { /* private fields */ }Expand description
Rowid handles are used to represent the unique identifier of a row in the
database. They cannot be created or set directly but are created implicitly
when a variable of type DPI_ORACLE_TYPE_ROWID is created. They are destroyed
when the last reference is released by a call to the function
dpiRowid_release().