#[repr(C)]pub struct dpiSodaColl { /* private fields */ }Expand description
SODA collection handles are used to represent SODA collections in the database.
They are created by calling one of the functions
dpiSodaDb_createCollection(), dpiSodaDb_openCollection() or
dpiSodaCollCursor_getNext() and are destroyed when the last reference
is released by calling the function dpiSodaColl_release().
See this tracking issue for known issues with SODA.