#[repr(C)]pub struct dpiSodaCollCursor { /* private fields */ }Expand description
SODA collection cursor handles are used to represent SODA collection cursors.
They are created by calling the function dpiSodaDb_getCollections()
and are destroyed when the last reference is released by calling the function
dpiSodaCollCursor_release().
See this tracking issue for known issues with SODA.