#[repr(C)]pub struct dpiSodaDb { /* private fields */ }Expand description
SODA database handles are used to represent connections to the SODA database.
They are created by calling the function dpiConn_getSodaDb(). They are
destroyed when the last reference is released by calling
dpiSodaDb_release().
See this tracking issue for known issues with SODA.