#[repr(C)]pub struct dpiSodaDoc { /* private fields */ }Expand description
SODA document handles are used to represent SODA documents in the database.
They are created by calling one of the functions
dpiSodaDb_createDocument(), dpiSodaDocCursor_getNext(),
dpiSodaColl_findOne(), dpiSodaColl_getDataGuide(),
dpiSodaColl_insertMany(), dpiSodaColl_insertOne(),
dpiSodaColl_replaceOne() or dpiSodaColl_save() and
are destroyed when the last reference is released by calling the function
dpiSodaDoc_release().
See this tracking issue for known issues with SODA.