#[repr(C)]pub struct dpiSodaDocCursor { /* private fields */ }Expand description
SODA document cursor handles are used to represent SODA document cursors.
They are created by calling the function dpiSodaColl_find()
and are destroyed when the last reference is released by calling the function
dpiSodaDocCursor_release().
See this tracking issue for known issues with SODA.