dpiSodaOperOptions

Struct dpiSodaOperOptions 

#[repr(C)]
pub struct dpiSodaOperOptions {
Show 15 fields pub numKeys: u32, pub keys: *mut *const c_char, pub keyLengths: *mut u32, pub key: *const c_char, pub keyLength: u32, pub version: *const c_char, pub versionLength: u32, pub filter: *const c_char, pub filterLength: u32, pub skip: u32, pub limit: u32, pub fetchArraySize: u32, pub hint: *const c_char, pub hintLength: u32, pub lock: c_int,
}
This structure is used for passing search criteria to a number of SODA operations. It is initialized using the function dpiContext_initSodaOperOptions() and used by the functions dpiSodaColl_find(), dpiSodaColl_findOne(), dpiSodaColl_getDocCount(), dpiSodaColl_remove() and dpiSodaColl_replaceOne().

Fields

numKeys: u32

Specifies the number of elements in the members [dpiSodaOperOptions.keys] and [dpiSodaOperOptions.keyLengths].

keys: *mut *const c_char

Specifies an array of key values which documents in the collection must have in order to be processed by the operation. The length of this array is defined by the member [dpiSodaOperOptions.numKeys].

keyLengths: *mut u32

Specifies an array of key length values. Each element corresponds to the length of the key (in bytes) found in the member [dpiSodaOperOptions.keys] at the same element index. The length of this array is defined by the member [dpiSodaOperOptions.numKeys].

key: *const c_char

Specifies the key which the document must have in order to be processed by the operation.

keyLength: u32

Specifies the length of the member [dpiSodaOperOptions.key], in bytes.

version: *const c_char

Specifies the document version that documents must have in order to be processed by the operation. This is typically used in conjunction with [dpiSodaOperOptions.key] and allows for opportunistic locking, so that operations do not affect a document that someone else has already modified.

versionLength: u32

Specifies the length of the member [dpiSodaOperOptions.version], in bytes.

filter: *const c_char

Specifies a filter value which limits the documents processed by the operation. See Overview of SODA Filter Specifications (QBEs).

filterLength: u32

Specifies the length of the member [dpiSodaOperOptions.filter], in bytes.

skip: u32

Specifies the number of documents to skip before processing documents in the collection. A value of 0 will result in no documents being skipped.

limit: u32

Specifies the maximum number of documents to process in the collection. A value of 0 means no limit is enforced.

fetchArraySize: u32

Specifies the number of documents that will be fetched at one time from a SODA collection. Increasing this value reduces the number of round-trips to the database but increases the amount of memory allocated. A value of 0 means that the default value (100) is used. This member is only supported in Oracle Client 19.5 and higher.

hint: *const c_char

Specifies a hint that will be passed through to the SODA operation. These hints are the same as the hints used for normal SQL operations but without the enclosing comment characters. This member is only supported in Oracle Client 21.3 and higher (also available in Oracle Client 19 from 19.11).

hintLength: u32

Specifies the length of the member [dpiSodaOperOptions.hint], in bytes. This member is only supported in Oracle Client 21.3 and higher (also available in Oracle Client 19 from 19.11).

lock: c_int

Specifies whether the documents fetched from the collection should be locked (equivalent to SQL “select for update”). The next commit or rollback on the connection made after the operation is performed will “unlock” the documents. Ensure that the flag DPI_SODA_FLAGS_ATOMIC_COMMIT is not used for the operation as otherwise the lock will be removed immediately.

This member should only be used with read operations (other than dpiSodaColl_getDocCount()) and should not be used in conjunction with the [dpiSodaOperOptions.skip] and [dpiSodaOperOptions.limit] members.

If this member is specified in conjunction with a write operation the value is ignored.

This member is only supported in Oracle Client 21.3 and higher (also available in Oracle Client 19 from 19.11).