#[repr(C)]pub struct dpiStmt { /* private fields */ }Expand description
Statement handles are used to represent statements of all types (queries, DML,
DDL and PL/SQL). They are created by calling the function
dpiConn_prepareStmt() or the function dpiSubscr_prepareStmt().
They are also created implicitly when a variable of type DPI_ORACLE_TYPE_STMT
is created. Statement handles can be closed by calling the function
dpiStmt_close() or by releasing the last reference to the statement by
calling the function dpiStmt_release().