dpiStmtInfo

Struct dpiStmtInfo 

#[repr(C)]
pub struct dpiStmtInfo { pub isQuery: c_int, pub isPLSQL: c_int, pub isDDL: c_int, pub isDML: c_int, pub statementType: dpiStatementType, pub isReturning: c_int, }
This structure is used for passing information about a statement from ODPI-C. It is used by the function dpiStmt_getInfo().

Fields

isQuery: c_int

Specifies if the statement refers to a query (1) or not (0).

isPLSQL: c_int

Specifies if the statement refers to a PL/SQL block (1) or not (0).

isDDL: c_int

Specifies if the statement refers to DDL (data definition language) such as creating a table (1) or not (0).

isDML: c_int

Specifies if the statement refers to DML (data manipulation language) such as inserting, updating and deleting (1) or not (0).

statementType: dpiStatementType

Specifies the type of statement that has been prepared. The members [dpiStmtInfo.isQuery], [dpiStmtInfo.isPLSQL], [dpiStmtInfo.isDDL] and [dpiStmtInfo.isDML] are all categorizations of this value. It will be one of the values from the enumeration dpiStatementType.

isReturning: c_int

Specifies if the statement has a returning clause in it (1) or not (0).