#[repr(C)]pub struct dpiStringList {
pub __bindgen_anon_1: dpiStringList__bindgen_ty_1,
pub __bindgen_anon_2: dpiStringList__bindgen_ty_2,
pub __bindgen_anon_3: dpiStringList__bindgen_ty_3,
}Expand description
This structure is used for receiving a list of strings from such functions as
dpiSodaDb_getCollectionNames() and dpiSodaColl_listIndexes().
The memory referenced by this structure should be freed by the function
dpiContext_freeStringList() and should not be manipulated directly.
Fields
__bindgen_anon_1: dpiStringList__bindgen_ty_1__bindgen_anon_2: dpiStringList__bindgen_ty_2__bindgen_anon_3: dpiStringList__bindgen_ty_3Trait Implementations
Sourceimpl Clone for dpiStringList
impl Clone for dpiStringList
Sourcefn clone(&self) -> dpiStringList
fn clone(&self) -> dpiStringList
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for dpiStringList
impl Default for dpiStringList
impl Copy for dpiStringList