dpiSubscrMessage

Struct dpiSubscrMessage 

#[repr(C)]
pub struct dpiSubscrMessage {
Show 17 fields pub eventType: dpiEventType, pub dbName: *const c_char, pub dbNameLength: u32, pub tables: *mut dpiSubscrMessageTable, pub numTables: u32, pub queries: *mut dpiSubscrMessageQuery, pub numQueries: u32, pub errorInfo: *mut dpiErrorInfo, pub txId: *const c_void, pub txIdLength: u32, pub registered: c_int, pub queueName: *const c_char, pub queueNameLength: u32, pub consumerName: *const c_char, pub consumerNameLength: u32, pub aqMsgId: *const c_void, pub aqMsgIdLength: u32,
}
This structure is used for passing messages sent by notifications to subscriptions. It is the second parameter to the callback method specified in the dpiSubscrCreateParams structure.

Fields

eventType: dpiEventType

Specifies the type of event that took place which generated the notification. It will be one of the values from the enumeration dpiEventType.

dbName: *const c_char

Specifies the name of the database which generated the notification, as a byte string in the encoding used for CHAR data. This value is not populated when the [dpiSubscrMessage.eventType] member is set to the values DPI_EVENT_AQ or DPI_EVENT_DEREG.

dbNameLength: u32

Specifies the length of the [dpiSubscrMessage.dbName] member, in bytes.

tables: *mut dpiSubscrMessageTable

Specifies a pointer to an array of dpiSubscrMessageTable structures representing the list of tables that were modified and generated this notification. This value is only populated when the value of the [dpiSubscrMessage.eventType] member is set to DPI_EVENT_OBJCHANGE.

numTables: u32

Specifies the number of structures available in the [dpiSubscrMessage.tables] member.

queries: *mut dpiSubscrMessageQuery

Specifies a pointer to an array of dpiSubscrMessageQuery structures representing the list of queries that were modified and generated this notification. This value is only populated when the value of the [dpiSubscrMessage.eventType] member is set to DPI_EVENT_QUERYCHANGE.

numQueries: u32

Specifies the number of structures available in the [dpiSubscrMessage.queries] member.

errorInfo: *mut dpiErrorInfo

Specifies a pointer to a dpiErrorInfo structure. This value will be NULL if no error has taken place. If this value is not NULL the other members in this structure will not be populated.

txId: *const c_void

Specifies the id of the transaction which generated the notification, as a series of bytes. This value is not populated when the [dpiSubscrMessage.eventType] member is set to the values DPI_EVENT_AQ or DPI_EVENT_DEREG.

txIdLength: u32

Specifies the length of the [dpiSubscrMessage.txId] member, in bytes.

registered: c_int

Specifies whether the subscription is registered with the database (1) or not (0). The subscription is automatically deregistered with the database when the subscription timeout value is reached or when the first notification is sent (when the quality of service flag DPI_SUBSCR_QOS_DEREG_NFY is used).

queueName: *const c_char

Specifies the name of the queue which has messages available to dequeue, as a byte string in the encoding used for CHAR data. This value is only populated when the [dpiSubscrMessage.eventType] member is set to the value DPI_EVENT_AQ.

queueNameLength: u32

Specifies the length of the [dpiSubscrMessage.queueName] member, in bytes.

consumerName: *const c_char

Specifies the consumer name of the queue which has messages available to dequeue, as a byte string in the encoding used for CHAR data. This value is only populated when the [dpiSubscrMessage.eventType] member is set to the value DPI_EVENT_AQ. It is also only populated if the queue that has messages to dequeue is a multi-consumer queue.

consumerNameLength: u32

Specifies the length of the [dpiSubscrMessage.consumerName] member, in bytes.

aqMsgId: *const c_void

Specifies message id of the message which is available to dequeue, as a series of bytes. This value is only populated when the [dpiSubscrMessage.eventType] member is set to the value DPI_EVENT_AQ.

aqMsgIdLength: u32

Specifies the length of the [dpiSubscrMessage.aqMsgId] member, in bytes.