#[repr(C)]pub struct dpiSubscrMessageQuery {
pub id: u64,
pub operation: dpiOpCode,
pub tables: *mut dpiSubscrMessageTable,
pub numTables: u32,
}Expand description
This structure is used for passing information on query change notification
events and is part of the dpiSubscrMessage structure.
Fields
id: u64Specifies the id of the query that was registered as part of the subscription that generated this notification.
operation: dpiOpCodeSpecifies the operations that took place on the registered query. It will
be one or more of the values from the enumeration
dpiOpCode, OR’ed together.
tables: *mut dpiSubscrMessageTableSpecifies a pointer to an array of
dpiSubscrMessageTable structures representing
the list of tables that were modified by the event which generated this
notification.
numTables: u32Specifies the number of structures available in the
[dpiSubscrMessageQuery.tables] member.