#[repr(C)]pub struct dpiSubscrMessageRow {
pub operation: dpiOpCode,
pub rowid: *const c_char,
pub rowidLength: u32,
}Expand description
This structure is used for passing information on the rows that were changed and resulted in the notification message of which this structure is a part.
Fields
operation: dpiOpCodeSpecifies the operations that took place on the registered query. It will
be one or more of the values from the enumeration
dpiOpCode, OR’ed together.
rowid: *const c_charSpecifies the rowid of the row that was changed, in the encoding used for CHAR data.
rowidLength: u32Specifies the length of the [dpiSubscrMessageRow.rowid] member, in
bytes.