#[repr(C)]pub struct dpiSubscrMessageTable {
pub operation: dpiOpCode,
pub name: *const c_char,
pub nameLength: u32,
pub rows: *mut dpiSubscrMessageRow,
pub numRows: u32,
}Expand description
This structure is used for passing information on the tables that were changed and resulted in the notification message of which this structure is a part.
Fields
operation: dpiOpCodeSpecifies the operations that took place on the modified table. It will
be one or more of the values from the enumeration
dpiOpCode, OR’ed together.
name: *const c_charSpecifies the name of the table that was changed, in the encoding used for CHAR data.
nameLength: u32Specifies the length of the [dpiSubscrMessageRow.name] member, in
bytes.
rows: *mut dpiSubscrMessageRowSpecifies a pointer to an array of
dpiSubscrMessageRow structures representing the
list of rows that were modified by the event which generated this
notification.
numRows: u32Specifies the number of structures available in the
[dpiSubscrMessageTable.rows] member.