dpiTimestamp

Struct dpiTimestamp 

#[repr(C)]
pub struct dpiTimestamp { pub year: i16, pub month: u8, pub day: u8, pub hour: u8, pub minute: u8, pub second: u8, pub fsecond: u32, pub tzHourOffset: i8, pub tzMinuteOffset: i8, }
This structure is used for passing timestamp data to and from the database in the structure dpiData.

Fields

year: i16

Specifies the year for the timestamp.

month: u8

Specifies the month for the timestamp. This should be between 1 and 12.

day: u8

Specifies the day for the timestamp. This should be between 1 and 31.

hour: u8

Specifies the hour for the timestamp. This should be between 0 and 23.

minute: u8

Specifies the minute for the timestamp. This should be between 0 and 59.

second: u8

Specifies the second for the timestamp. This should be between 0 and 59.

fsecond: u32

Specifies the fractional seconds for the timestamp, in nanoseconds.

tzHourOffset: i8

Specifies the hours offset from UTC. This value is only used for timestamp with time zone and timestamp with local time zone columns.

tzMinuteOffset: i8

Specifies the minutes offset from UTC. This value is only used for timestamp with time zone and timestamp with local time zone columns. Note that this value will be negative in the western hemisphere. For example, when the timezone is -03:30, tzHourOffset will be -3 and tzMinuteOffset will be -30.