#[repr(C)]pub struct dpiVar { /* private fields */ }Expand description
Variable handles are used to represent memory areas used for transferring data
to and from the database. They are created by calling the function
dpiConn_newVar(). They are destroyed when the last reference to the
variable is released by calling the function dpiVar_release(). They are
bound to statements by calling the function dpiStmt_bindByName() or the
function dpiStmt_bindByPos(). They can also be used for fetching data
from the database by calling the function dpiStmt_define().