dpiVector

Struct dpiVector 

#[repr(C)]
pub struct dpiVector { /* private fields */ }
Vector handles are used to represent vector values stored in the database. They are only available from Oracle Client and Database 23.4 and higher. They can be created explicitly by a call to dpiConn_newVector() or implicitly when a variable of type DPI_ORACLE_TYPE_VECTOR is created. They are destroyed when the last reference is released by a call to the function dpiVector_release().