#[repr(C)]pub struct dpiVersionInfo {
pub versionNum: c_int,
pub releaseNum: c_int,
pub updateNum: c_int,
pub portReleaseNum: c_int,
pub portUpdateNum: c_int,
pub fullVersionNum: u32,
}Expand description
This structure is used for returning Oracle version information about the
Oracle Client (dpiContext_getClientVersion()) and Oracle Database
(dpiConn_getServerVersion()).
Fields
versionNum: c_intSpecifies the major version of the Oracle Client or Database.
releaseNum: c_intSpecifies the release version of the Oracle Client or Database.
updateNum: c_intSpecifies the update version of the Oracle Client or Database.
portReleaseNum: c_intSpecifies the port specific release version of the Oracle Client or Database.
portUpdateNum: c_intSpecifies the port specific update version of the Oracle Client or Database.
fullVersionNum: u32Specifies the full version (all five components) as a number that is suitable for comparison with the result of the macro DPI_ORACLE_VERSION_TO_NUMBER.