dpiCreateMode

Type Alias dpiCreateMode 

pub type dpiCreateMode = u32;
This enumeration identifies the mode to use when creating connections to the database. Note that the OCI objects mode is always enabled.

ValueDescription
DPI_MODE_CREATE_DEFAULTDefault value used when creating connections.
DPI_MODE_CREATE_EVENTSEnables events mode which is required for the use of advanced queuing (AQ) and continuous query notification (CQN).
DPI_MODE_CREATE_THREADEDEnables threaded mode. Internal OCI structures not exposed to the user are protected from concurrent access by multiple threads. Error information is also managed in thread local storage.