dpiDeqNavigation

Type Alias dpiDeqNavigation 

pub type dpiDeqNavigation = u32;
This enumeration identifies the method used for determining which message is to be dequeued from a queue.

ValueDescription
DPI_DEQ_NAV_FIRST_MSGRetrieves the first available message that matches the search criteria. This resets the position to the beginning of the queue.
DPI_DEQ_NAV_NEXT_MSGRetrieves the next available message that matches the search criteria. This is the default method.
DPI_DEQ_NAV_NEXT_TRANSACTIONSkips the remainder of the current transaction group (if any) and retrieves the first message of the next transaction group. This option can only be used if message grouping is enabled for the queue.