dpiEventType

Type Alias dpiEventType 

pub type dpiEventType = u32;
This enumeration identifies the types of events that can take place. The event type is part of the messages that are sent to subscriptions.

ValueDescription
DPI_EVENT_AQIndicates that a queue has messages available to dequeue.
DPI_EVENT_DEREGIndicates that a subscription is no longer registered with the database and will no longer generate events.
DPI_EVENT_NONEIndicates that no event has taken place.
DPI_EVENT_OBJCHANGEIndicates that an object change has taken place.
DPI_EVENT_QUERYCHANGEIndicates that a query change has taken place.
DPI_EVENT_SHUTDOWNIndicates that a database is being shut down.
DPI_EVENT_SHUTDOWN_ANYIndicates that an instance of Oracle Real Application Clusters (RAC) is being shut down.
DPI_EVENT_STARTUPIndicates that a database is being started up.