dpiExecMode

Type Alias dpiExecMode 

pub type dpiExecMode = u32;
This enumeration identifies the available modes for executing statements using dpiStmt_execute() and dpiStmt_executeMany().

ValueDescription
DPI_MODE_EXEC_ARRAY_DML_ROWCOUNTSEnable getting row counts for each DML operation when performing an array DML execution. The actual row counts can be retrieved using the function dpiStmt_getRowCounts().
DPI_MODE_EXEC_BATCH_ERRORSEnable batch error mode. This permits an an array DML operation to succeed even if some of the individual operations fail. The errors can be retrieved using the function dpiStmt_getBatchErrors().
DPI_MODE_EXEC_COMMIT_ON_SUCCESSIf execution completes successfully, the current active transaction is committed.
DPI_MODE_EXEC_DEFAULTDefault mode for execution. Metadata is made available after queries are executed.
DPI_MODE_EXEC_DESCRIBE_ONLYDo not execute the statement but simply acquire the metadata for the query.
DPI_MODE_EXEC_PARSE_ONLYDo not execute the statement but only parse it and return any parse errors. Note that using this mode with a DDL statement will result in the statement being executed.