dpiMessageState

Type Alias dpiMessageState 

pub type dpiMessageState = u32;
This enumeration identifies the possible states for messages in a queue.

ValueDescription
DPI_MSG_STATE_EXPIREDThe message has been moved to the exception queue.
DPI_MSG_STATE_PROCESSEDThe message has already been processed and is retained.
DPI_MSG_STATE_READYThe message is ready to be processed.
DPI_MSG_STATE_WAITINGThe message is waiting for the delay time to expire.