dpiPoolCloseMode

Type Alias dpiPoolCloseMode 

pub type dpiPoolCloseMode = u32;
This enumeration identifies the mode to use when closing pools.

ValueDescription
DPI_MODE_POOL_CLOSE_DEFAULTDefault value used when closing pools. If there are any active sessions in the pool an error will be raised.
DPI_MODE_POOL_CLOSE_FORCECauses all of the active connections in the pool to be closed before closing the pool itself.