dpiPurity

Type Alias dpiPurity 

pub type dpiPurity = u32;
This enumeration identifies the purity of the sessions that are acquired when using connection classes during connection creation.

ValueDescription
DPI_PURITY_DEFAULTDefault value used when creating connections.
DPI_PURITY_NEWA connection is required that has not been tainted with any prior session state.
DPI_PURITY_SELFA connection is permitted to have prior session state.