dpiServerType

Type Alias dpiServerType 

pub type dpiServerType = u8;
This enumeration identifies the type of server process associated with a connection. It is only available with Oracle Client libraries 23.4 or higher.

ValueDescription
DPI_SERVER_TYPE_DEDICATEDA dedicated server process is being used with the connection.
DPI_SERVER_TYPE_POOLEDA pooled server process (DRCP) is being used with the connection.
DPI_SERVER_TYPE_SHAREDA shared server process is being used with the connection.
DPI_SERVER_TYPE_UNKNOWNThe type of server process is unknown.