dpiShutdownMode

Type Alias dpiShutdownMode 

pub type dpiShutdownMode = u32;
This enumeration identifies the mode to use when shutting down a database using dpiConn_shutdownDatabase().

ValueDescription
DPI_MODE_SHUTDOWN_ABORTAll uncommitted transactions are terminated and are not rolled back. This is the fastest way to shut down the database but the next database startup may require instance recovery.
DPI_MODE_SHUTDOWN_DEFAULTFurther connections to the database are prohibited. Wait for users to disconnect from the database.
DPI_MODE_SHUTDOWN_FINALShuts down the database. This mode should only be used in the second call to dpiConn_shutdownDatabase().
DPI_MODE_SHUTDOWN_IMMEDIATEAll uncommitted transactions are terminated and rolled back and all connections to the database are closed immediately.
DPI_MODE_SHUTDOWN_TRANSACTIONALFurther connections to the database are prohibited and no new transactions are allowed to be started. Wait for active transactions to complete.
DPI_MODE_SHUTDOWN_TRANSACTIONAL_LOCALBehaves the same way as DPI_MODE_SHUTDOWN_TRANSACTIONAL but only waits for local transactions to complete.