dpiSodaFlags

Type Alias dpiSodaFlags 

pub type dpiSodaFlags = u32;
This enumeration identifies the flags that can be used with SODA functions.

ValueDescription
DPI_SODA_FLAGS_ATOMIC_COMMITIf the function completes successfully the current transaction is committed. If it does not complete successfully, no changes to the database are made and the existing transaction is left untouched.
DPI_SODA_FLAGS_CREATE_COLL_MAPCreate collection in MAP mode. This mode is only supported in dpiSodaDb_createCollection().
DPI_SODA_FLAGS_DEFAULTDefault value.
DPI_SODA_FLAGS_INDEX_DROP_FORCEForcibly drop the index. This mode is only supported in dpiSodaColl_dropIndex().