dpiStartupMode

Type Alias dpiStartupMode 

pub type dpiStartupMode = u32;
This enumeration identifies the mode to use when starting up a database using dpiConn_startupDatabase().

ValueDescription
DPI_MODE_STARTUP_DEFAULTDefault mode for startup which permits database access to all users.
DPI_MODE_STARTUP_FORCEShuts down a running instance (using ABORT) before starting a new one. This mode should only be used in unusual circumstances.
DPI_MODE_STARTUP_RESTRICTOnly allows database access to users with both the CREATE SESSION and RESTRICTED SESSION privileges (normally the DBA).