dpiStatementType

Type Alias dpiStatementType 

pub type dpiStatementType = u16;
This enumeration identifies the type of statement that has been prepared. It is available as part of the structure dpiStmtInfo.

ValueDescription
DPI_STMT_TYPE_ALTERIdentifies an alter statement. The member [dpiStmtInfo.isDDL] will be set to 1.
DPI_STMT_TYPE_BEGINIdentifies an anonymous PL/SQL block starting with the keyword begin. The member [dpiStmtInfo.isPLSQL] will be set to 1.
DPI_STMT_TYPE_CALLIdentifies a CALL statement used for calling stored procedures and functions. The member [dpiStmtInfo.isPLSQL] will be set to 1.
DPI_STMT_TYPE_COMMITIdentifies a commit statement.
DPI_STMT_TYPE_CREATEIdentifies a create statement. The member [dpiStmtInfo.isDDL] will be set to 1.
DPI_STMT_TYPE_DECLAREIdentifies an anonymous PL/SQL block starting with the keyword declare. The member [dpiStmtInfo.isPLSQL] will be set to 1.
DPI_STMT_TYPE_DELETEIdentifies a delete statement. The member [dpiStmtInfo.isDML] will be set to 1.
DPI_STMT_TYPE_DROPIdentifies a drop statement. The member [dpiStmtInfo.isDDL] will be set to 1.
DPI_STMT_TYPE_EXPLAIN_PLANIdentifies an explain plan statement. The member [dpiStmtInfo.isDML] will be set to 1.
DPI_STMT_TYPE_INSERTIdentifies an insert statement. The member [dpiStmtInfo.isDML] will be set to 1.
DPI_STMT_TYPE_MERGEIdentifies a merge statement. The member [dpiStmtInfo.isDML] will be set to 1.
DPI_STMT_TYPE_ROLLBACKIdentifies a rollback statement.
DPI_STMT_TYPE_SELECTIdentifies a select statement. The member [dpiStmtInfo.isQuery] will be set to 1.
DPI_STMT_TYPE_UPDATEIdentifies an update statement. The member [dpiStmtInfo.isDML] will be set to 1.
DPI_STMT_TYPE_UNKNOWNIndicates that the statement type is unknown.