dpiSubscrGroupingClass

Type Alias dpiSubscrGroupingClass 

pub type dpiSubscrGroupingClass = u8;
This enumeration identifies the grouping class. Instead of individual events being delivered to the callback, events are grouped before being sent to the callback. This enumeration is used in the dpiSubscrCreateParams structure.

ValueDescription
DPI_SUBSCR_GROUPING_CLASS_TIMEEvents are grouped by the period of time in which they are received.