dpiSubscrNamespace

Type Alias dpiSubscrNamespace 

pub type dpiSubscrNamespace = u32;
This enumeration identifies the namespaces supported by subscriptions.

ValueDescription
DPI_SUBSCR_NAMESPACE_AQIdentifies the namespace used for receiving notifications when messages are available to be dequeued in advanced queueing (AQ).
DPI_SUBSCR_NAMESPACE_DBCHANGEIdentifies the namespace used for receiving notifications for database object changes and query changes (CQN).