dpiSubscrProtocol

Type Alias dpiSubscrProtocol 

pub type dpiSubscrProtocol = u32;
This enumeration identifies the protocol used for sending notifications to subscriptions.

ValueDescription
DPI_SUBSCR_PROTO_CALLBACKNotifications are sent by calling the callback specified when the subscription was registered.
DPI_SUBSCR_PROTO_HTTPNotifications are sent to the URL specified when the subscription was registered.
DPI_SUBSCR_PROTO_MAILNotifications are sent by sending an e-mail to the e-mail address specified when the subscription was registered.
DPI_SUBSCR_PROTO_PLSQLNotifications are sent by calling the PL/SQL procedure specified when the subscription was registered.