dpiSubscrQOS

Type Alias dpiSubscrQOS 

pub type dpiSubscrQOS = u32;
This enumeration identifies the quality of service flags for sending notifications to subscriptions.

ValueDescription
DPI_SUBSCR_QOS_BEST_EFFORTPerform query notification in best effort mode which may result in notifications being sent when the query has not in fact changed. This is needed for complex queries that cannot be registered in guaranteed mode.
DPI_SUBSCR_QOS_DEREG_NFYWhen the notification has been received, the subscription is removed.
DPI_SUBSCR_QOS_QUERYPerform query notification instead of database change notification. Notification is done in guaranteed mode which guarantees that the query has in fact changed.
DPI_SUBSCR_QOS_RELIABLENotifications are sent reliably. If the database fails, the notifications are not lost. This is not supported for nonpersistent queues or buffered messaging.
DPI_SUBSCR_QOS_ROWIDSInformation on the rows affected by the database or query change is sent along with the notification.