dpiTpcEndFlags

Type Alias dpiTpcEndFlags 

pub type dpiTpcEndFlags = u32;
This enumeration identifies the flags that can be used when calling dpiConn_tpcEnd().

ValueDescription
DPI_TPC_END_NORMALNormal ending of the transaction.
DPI_TPC_END_SUSPENDTransaction is suspended and may be resumed at some later point.