dpiVectorFormat

Type Alias dpiVectorFormat 

pub type dpiVectorFormat = u8;
This enumeration identifies the storage format for a vector’s dimensions.

ValueDescription
DPI_VECTOR_FORMAT_BINARYThe vector dimension storage format is single bits, represented in groups of 8 as single byte unsigned integers.
DPI_VECTOR_FORMAT_FLOAT32The vector dimension storage format is single-precision floating point numbers.
DPI_VECTOR_FORMAT_FLOAT64The vector dimension storage format is double-precision floating point numbers.
DPI_VECTOR_FORMAT_INT8The vector dimension storage format is single byte signed integers.