dpiVisibility

Type Alias dpiVisibility 

pub type dpiVisibility = u32;
This enumeration identifies the visibility of messages in advanced queuing.

ValueDescription
DPI_VISIBILITY_IMMEDIATEThe message is not part of the current transaction but constitutes a transaction of its own.
DPI_VISIBILITY_ON_COMMITThe message is part of the current transaction. This is the default value.