pub unsafe extern "C" fn dpiConn_getObjectType(
conn: *mut dpiConn,
name: *const c_char,
nameLength: u32,
objType: *mut *mut dpiObjectType,
) -> c_intExpand description
Looks up an object type by name in the database and returns a reference to it. The reference should be released as soon as it is no longer needed.
The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.