pub unsafe extern "C" fn dpiContext_freeStringList(
context: *mut dpiContext,
list: *mut dpiStringList,
) -> c_intExpand description
Frees the memory associated with the string list allocated by a call to
one of the functions dpiSodaDb_getCollectionNames()
or dpiSodaColl_listIndexes(). This function should not be
called without first calling one of those functions first.
The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.