pub unsafe extern "C" fn dpiObjectType_createObject(
objType: *mut dpiObjectType,
obj: *mut *mut dpiObject,
) -> c_intExpand description
Creates an object of the specified type and returns a reference to it. This reference should be released as soon as it is no longer needed.
The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.