pub unsafe extern "C" fn dpiPool_acquireConnection(
pool: *mut dpiPool,
userName: *const c_char,
userNameLength: u32,
password: *const c_char,
passwordLength: u32,
createParams: *mut dpiConnCreateParams,
conn: *mut *mut dpiConn,
) -> c_intExpand description
Acquires a connection from the pool and returns a reference to it. This
reference should be released by calling dpiConn_release() as soon
as it is no longer needed, which will also return the connection back to
the pool for subsequent calls to this function. The connection can be
returned back to the pool earlier by calling dpiConn_close().
The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.