pub unsafe extern "C" fn dpiPool_create(
context: *const dpiContext,
userName: *const c_char,
userNameLength: u32,
password: *const c_char,
passwordLength: u32,
connectString: *const c_char,
connectStringLength: u32,
commonParams: *const dpiCommonCreateParams,
createParams: *mut dpiPoolCreateParams,
pool: *mut *mut dpiPool,
) -> c_intExpand description
Creates a session pool which creates and maintains a group of stateless sessions to the database. The main benefit of session pooling is performance since making a connection to the database is a time-consuming activity, especially when the database is remote.
The function returns DPI_SUCCESS for success and DPI_FAILURE for failure. If a failure occurs, the errorInfo structure is filled in with error information.