pub unsafe extern "C" fn dpiPool_getStmtCacheSize(
pool: *mut dpiPool,
cacheSize: *mut u32,
) -> c_intExpand description
Returns the default size of the statement cache for sessions in the pool, in number of statements.
The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.