pub unsafe extern "C" fn dpiPool_getTimeout(
pool: *mut dpiPool,
value: *mut u32,
) -> c_intExpand description
Returns the length of time (in seconds) after which idle sessions in the pool are terminated. Note that termination only occurs when the pool is accessed. A value of 0 means that no ide sessions are terminated.
The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.