pub unsafe extern "C" fn dpiPool_setSodaMetadataCache(
pool: *mut dpiPool,
enabled: c_int,
) -> c_intExpand description
Sets whether the SODA metadata cache is enabled or not. Enabling the SODA
metadata cache can significantly improve the performance of repeated calls
to methods dpiSodaDb_createCollection() (when not specifying a
value for the metadata parameter) and dpiSodaDb_openCollection().
Note that the cache can become out of date if changes to the metadata of
cached collections are made externally.
The SODA metadata cache requires Oracle Client 21.3, or later. It is also available in Oracle Client 19 from 19.11.
The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.