pub unsafe extern "C" fn dpiPool_setTimeout(
pool: *mut dpiPool,
value: u32,
) -> c_intExpand description
Sets the amount of time (in seconds) after which idle sessions in the pool are terminated. Note that termination only occurs when the pool is accessed. A value of zero will result in no idle sessions being terminated.
The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.