pub unsafe extern "C" fn dpiPool_setWaitTimeout(
pool: *mut dpiPool,
value: u32,
) -> c_intExpand description
Sets the amount of time (in milliseconds) that the caller should wait for a session to be available in the pool before returning with an error.
The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.