dpiQueue_addRef

Function dpiQueue_addRef 

pub unsafe extern "C" fn dpiQueue_addRef(
    queue: *mut dpiQueue,
) -> c_int
Adds a reference to the queue. This is intended for situations where a reference to the queue needs to be maintained independently of the reference returned when the queue was created.

The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.