pub unsafe extern "C" fn dpiStmt_bindByName(
stmt: *mut dpiStmt,
name: *const c_char,
nameLength: u32,
var: *mut dpiVar,
) -> c_intExpand description
Binds a variable to a named placeholder in the statement. A reference to the variable is retained by the library and is released when the statement itself is released or a new variable is bound to the same name.
The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.