pub unsafe extern "C" fn dpiStmt_defineValue(
stmt: *mut dpiStmt,
pos: u32,
oracleTypeNum: dpiOracleTypeNum,
nativeTypeNum: dpiNativeTypeNum,
size: u32,
sizeIsBytes: c_int,
objType: *mut dpiObjectType,
) -> c_intExpand description
Defines the type of data that will be used to fetch rows from the
statement. This is intended for use with the function
dpiStmt_getQueryValue(), when the default data type derived from
the column metadata needs to be overridden by the application. Internally,
a variable is created with the specified data type and size.
The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.