pub unsafe extern "C" fn dpiStmt_executeMany(
stmt: *mut dpiStmt,
mode: dpiExecMode,
numIters: u32,
) -> c_intExpand description
Executes the statement the specified number of times using the bound values. Each bound variable must have at least this many elements allocated or an error is returned.
The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.