pub unsafe extern "C" fn dpiStmt_getRowCounts(
stmt: *mut dpiStmt,
numRowCounts: *mut u32,
rowCounts: *mut *mut u64,
) -> c_intExpand description
Returns an array of row counts affected by the last invocation of
dpiStmt_executeMany() with the array DML rowcounts mode enabled.
This feature is only available if both client and server are at 12.1.
The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.