pub unsafe extern "C" fn dpiStmt_setPrefetchRows(
stmt: *mut dpiStmt,
numRows: u32,
) -> c_intExpand description
Sets the number of rows that will be prefetched by the Oracle Client library when a query is executed. The default value is DPI_DEFAULT_PREFETCH_ROWS (2). Increasing this value may reduce the number of round-trips to the database that are required in order to fetch rows, but at the cost of increasing memory requirements. Setting this value to 0 will disable prefetch completely, which may be useful when the timing for fetching rows must be controlled by the caller.
The current value can be determined by calling
dpiStmt_getPrefetchRows().
The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.