dpiVar_addRef

Function dpiVar_addRef 

pub unsafe extern "C" fn dpiVar_addRef(var: *mut dpiVar) -> c_int
Adds a reference to the variable. This is intended for situations where a reference to the variable needs to be maintained independently of the reference returned when the variable was created.

The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.