dpiVar_getNumElementsInArray

Function dpiVar_getNumElementsInArray 

pub unsafe extern "C" fn dpiVar_getNumElementsInArray(
    var: *mut dpiVar,
    numElements: *mut u32,
) -> c_int
Returns the number of elements in a PL/SQL index-by table if the variable was created as an array by the function dpiConn_newVar(). If the variable is one of the output bind variables of a DML returning statement, however, the value returned will correspond to the number of rows returned by the DML returning statement. In all other cases, the value returned will be the number of elements the variable was created with.

The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.