pub unsafe extern "C" fn dpiVar_release(var: *mut dpiVar) -> c_intExpand description
Releases a reference to the variable. A count of the references to the variable is maintained and when this count reaches zero, the memory associated with the variable is freed.
The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.