pub unsafe extern "C" fn dpiVector_addRef(
vector: *mut dpiVector,
) -> c_intExpand description
Adds a reference to the vector value. This is intended for situations where a reference to the vector value needs to be maintained independently of the reference returned when the vector value was created.
The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.