pub unsafe extern "C" fn dpiVector_release(
vector: *mut dpiVector,
) -> c_intExpand description
Releases a reference to the vector value. A count of the references to the vector value is maintained and when this count reaches zero, the memory associated with the vector value is freed.
The function returns DPI_SUCCESS for success and DPI_FAILURE for failure.