#[repr(C)]pub struct dpiAppContext {
pub namespaceName: *const c_char,
pub namespaceNameLength: u32,
pub name: *const c_char,
pub nameLength: u32,
pub value: *const c_char,
pub valueLength: u32,
}Expand description
This structure is used for passing application context to the database during
the process of creating standalone connections. These values are ignored when
acquiring a connection from a session pool or when using DRCP (Database
Resident Connection Pooling). All values must be set to valid values prior to
being used in the dpiConnCreateParams structure and
must remain valid until the execution of dpiConn_create() completes.
Values set using this structure are available in logon triggers by using the
sys_context() SQL function.
Fields
namespaceName: *const c_charSpecifies the value of the “namespace” parameter to sys_context(). It is
expected to be a byte string in the encoding specified in the
dpiConnCreateParams structure and must not be
NULL.
namespaceNameLength: u32Specifies the length of the [dpiAppContext.namespaceName] member,
in bytes.
name: *const c_charSpecifies the value of the “parameter” parameter to sys_context(). It is
expected to be a byte string in the encoding specified in the
dpiConnCreateParams structure and must not be
NULL.
nameLength: u32Specifies the length of the [dpiAppContext.name] member, in bytes.
value: *const c_charSpecifies the value that will be returned from sys_context(). It is
expected to be a byte string in the encoding specified in the
dpiConnCreateParams structure and must not be
NULL.
valueLength: u32Specifies the length of the [dpiAppContext.value] member, in bytes.