#[repr(C)]pub struct dpiCommonCreateParams {
pub createMode: dpiCreateMode,
pub encoding: *const c_char,
pub nencoding: *const c_char,
pub edition: *const c_char,
pub editionLength: u32,
pub driverName: *const c_char,
pub driverNameLength: u32,
pub sodaMetadataCache: c_int,
pub stmtCacheSize: u32,
pub accessToken: *mut dpiAccessToken,
}Expand description
This structure is used for creating session pools and standalone connections to
the database. All members are initialized to default values using the
dpiContext_initCommonCreateParams() function.
Fields
createMode: dpiCreateModeSpecifies the mode used for creating connections. It is expected to be
one or more of the values from the enumeration
dpiCreateMode, OR’ed together. The default value is
DPI_MODE_CREATE_DEFAULT.
Note that when this structure is used during creation of a pool, the mode DPI_MODE_CREATE_THREADED is automatically enabled regardless of what value is set in this member.
encoding: *const c_charSpecifies the encoding to use for CHAR data, as a null-terminated ASCII
string. Either an IANA or Oracle specific character set name is expected.
NULL is also acceptable which implies the use of the NLS_LANG environment
variable (or ASCII, if the NLS_LANG environment variable is not set).
The default value is the value of the member
[dpiContextCreateParams.defaultEncoding] specified when the call to
dpiContext_createWithParams() was made.
nencoding: *const c_charSpecifies the encoding to use for NCHAR data, as a null-terminated ASCII
string. Either an IANA or Oracle specific character set name is expected.
NULL is also acceptable which implies the use of the NLS_NCHAR environment
variable (or the same value as the [dpiCommonCreateParams.encoding]
member if the NLS_NCHAR environment variable is not set). The default
value is the value of the member
[dpiContextCreateParams.defaultEncoding] specified when the call to
dpiContext_createWithParams() was made.
edition: *const c_charSpecifies the edition to be used when creating a standalone connection. It
is expected to be NULL (meaning that no edition is set) or a byte string in
the encoding specified by the [dpiCommonCreateParams.encoding]
member. The default value is NULL.
editionLength: u32Specifies the length of the [dpiCommonCreateParams.edition] member,
in bytes. The default value is 0.
driverName: *const c_charSpecifies the name of the driver that is being used. It is expected to be
NULL or a byte string in the encoding specified by the
[dpiCommonCreateParams.encoding] member. The default value is the
value of the member [dpiContextCreateParams.defaultDriverName]
specified when the call to
dpiContext_createWithParams() was made.
driverNameLength: u32Specifies the length of the [dpiCommonCreateParams.driverName]
member, in bytes. The default value is the length of the member
[dpiContextCreateParams.defaultDriverName] specified when the call
to dpiContext_createWithParams() was made.
sodaMetadataCache: c_intSpecifies whether to enable the SODA metadata cache or not, which can
significantly improve the performance of repeated calls to methods
dpiSodaDb_createCollection() (when not specifying a value for the
metadata parameter) and dpiSodaDb_openCollection(). This requires
Oracle Client 21.3 or higher (also available in Oracle Client 19 from
19.11).
stmtCacheSize: u32Specifies the number of statements to retain in the statement cache. Use a value of 0 to disable the statement cache completely.
accessToken: *mut dpiAccessTokenSpecifies a pointer to a dpiAccessToken structure.
Each member of structure is populated with authentication parameters used for
token based authentication. This requires Oracle Client 19.4 (or later),
or 21.5 (or later).