#[repr(C)]pub struct dpiConnInfo {
pub dbDomain: *const c_char,
pub dbDomainLength: u32,
pub dbName: *const c_char,
pub dbNameLength: u32,
pub instanceName: *const c_char,
pub instanceNameLength: u32,
pub serviceName: *const c_char,
pub serviceNameLength: u32,
pub maxIdentifierLength: u32,
pub maxOpenCursors: u32,
pub serverType: u8,
}Expand description
This structure is used for passing information about a connection from ODPI-C.
It is used by the function dpiConn_getInfo().
Fields
dbDomain: *const c_charA pointer to the name of the Oracle Database Domain name associated with
the connection, encoded in the encoding used for CHAR data. This is the
same value returned by the SQL expression
SELECT VALUE FROM V$PARAMETER WHERE NAME = 'db_domain'.
dbDomainLength: u32Contains the length of the [dpiConnInfo.dbDomain] member, in bytes.
dbName: *const c_charA pointer to the Oracle Database name associated with the connection,
encoded in the encoding used for CHAR data. This is the same value returned
by the SQL expression SELECT NAME FROM V$DATABASE. Note the values may
have different cases.
dbNameLength: u32Contains the length of the [dpiConnInfo.dbName] member, in bytes.
instanceName: *const c_charA pointer to the Oracle Database instance name associated with the
connection, encoded in the encoding used for CHAR data. This is the same
value returned by the SQL expression
SELECT SYS_CONTEXT('USERENV', 'INSTANCE_NAME') FROM DUAL. Note the
values may have different cases.
instanceNameLength: u32Contains the length of the [dpiConnInfo.instanceName] member, in
bytes.
serviceName: *const c_charA pointer to the Oracle Database service name associated with the
connection, encoded in the encoding used for CHAR data. This is the same
value returned by the SQL expression
SELECT SYS_CONTEXT('USERENV', 'SERVICE_NAME') FROM DUAL.
serviceNameLength: u32Contains the length of the [dpiConnInfo.serviceName] member, in
bytes.
maxIdentifierLength: u32Specifies the maximum length of identifiers (in bytes) supported by the database to which the connection has been established. See Database Object Naming Rules. The value may be 0, 30, or 128. The value 0 indicates the size cannot be reliably determined by ODPI-C, which occurs when using Oracle Client libraries 12.1 (or older) and also connected to Oracle Database 12.2, or later.
maxOpenCursors: u32Specifies the maximum number of cursors that can be opened. This is the
same value returned by the SQL expression
SELECT VALUE FROM V$PARAMETER WHERE NAME = 'open_cursors'.
serverType: u8Specifies the type of server process used by the connection. This value
will be one of the values in the enumeration
dpiServerType.