#[repr(C)]pub struct dpiContext { /* private fields */ }Expand description
Context handles are the top level handles created by the library and are used
for all error handling as well as creating pools and standalone connections to
the database. The first call to ODPI-C by any application must be
dpiContext_createWithParams() which will create the context as well as
validate the version used by the application. Context handles are destroyed by
using the function dpiContext_destroy().