#[repr(C)]pub struct dpiErrorInfo {
pub code: i32,
pub offset16: u16,
pub message: *const c_char,
pub messageLength: u32,
pub encoding: *const c_char,
pub fnName: *const c_char,
pub action: *const c_char,
pub sqlState: *const c_char,
pub isRecoverable: c_int,
pub isWarning: c_int,
pub offset: u32,
}Expand description
This structure is used for transferring error information from ODPI-C. All of the strings referenced here may become invalid as soon as the next ODPI-C call is made.
Fields
code: i32The OCI error code if an OCI error has taken place. If no OCI error has taken place the value is 0.
offset16: u16The 16-bit value of [dpiErrorInfo.offset] retained for backwards
compatibility. This member will be removed at some point in the future.
message: *const c_charThe error message as a byte string in the encoding specified by the
[dpiErrorInfo.encoding] member.
messageLength: u32The length of the [dpiErrorInfo.message] member, in bytes.
encoding: *const c_charThe encoding in which the error message is encoded as a null-terminated string. For OCI errors this is the CHAR encoding used when the connection was created. For ODPI-C specific errors this is UTF-8.
fnName: *const c_charThe public ODPI-C function name which was called in which the error took place. This is a null-terminated ASCII string.
action: *const c_charThe internal action that was being performed when the error took place. This is a null-terminated ASCII string.
sqlState: *const c_charThe SQLSTATE code associated with the error. This is a 5 character null-terminated string.
isRecoverable: c_intA boolean value indicating if the error is recoverable. This member always has a value of 0 unless both client and server are at release 12.1 or higher.
isWarning: c_intA boolean value indicating if the error information is for a warning returned by Oracle that does not prevent the requested operation from proceeding. Examples include connecting to the database with a password that is about to expire (within the grace period) and creating a stored procedure with compilation errors.
offset: u32The parse error offset (in bytes) when executing a statement or the row offset when performing bulk operations or fetching batch error information. If neither of these cases are true, the value is 0.