#[repr(C)]pub struct dpiJsonArray {
pub numElements: u32,
pub elements: *mut dpiJsonNode,
pub elementValues: *mut dpiDataBuffer,
}Expand description
This structure is used for passing JSON objects to and from the database.
Fields
numElements: u32Specifies the number of elements that are found in the JSON array. This also identifies the number of elements in each of the remaining arrays.
elements: *mut dpiJsonNodeSpecifies an array of JSON nodes that are the values of the elements found
in the JSON array. Each of these is a structure of type
dpiJsonNode.
elementValues: *mut dpiDataBufferSpecifies an array of buffers that contain the data for the values of the
elements found in the JSON array. This member should not be used directly.
Instead, the [dpiJsonNode.value] member of the corresponding node
in the member [dpiJsonArray.elements] should be used.