#[repr(C)]pub struct dpiObjectAttr { /* private fields */ }Expand description
Object attribute handles are used to represent the attributes of types such as
those created by the SQL command CREATE OR REPLACE TYPE. They are created by
calling the function dpiObjectType_getAttributes() and are destroyed
when the last reference is released by calling the function
dpiObjectAttr_release().