#[repr(C)]pub struct dpiShardingKeyColumn {
pub oracleTypeNum: dpiOracleTypeNum,
pub nativeTypeNum: dpiNativeTypeNum,
pub value: dpiDataBuffer,
}Expand description
This structure is used for passing sharding key column values to the database.
It is part of the structure dpiConnCreateParams.
Fields
oracleTypeNum: dpiOracleTypeNumSpecifies the Oracle type of the column which makes up the sharding key. It
is expected to be one of the values from the enumeration
dpiOracleTypeNum but currently only the value
DPI_ORACLE_TYPE_VARCHAR is supported.
nativeTypeNum: dpiNativeTypeNumSpecifies the native type of the column which makes up the sharding key. It
is expected to be one of the values from the enumeration
dpiNativeTypeNum but currently only the value
DPI_NATIVE_TYPE_BYTES is supported.
value: dpiDataBufferSpecifies the value of the column which makes up the sharding key. It is a
union of type dpiDataBuffer and the member of the
union that is set must correspond to the value of the member
[dpiShardingKeyColumn.nativeTypeNum].