pub type dpiServerType = u8;Expand description
This enumeration identifies the type of server process associated with a connection. It is only available with Oracle Client libraries 23.4 or higher.
| Value | Description |
|---|---|
DPI_SERVER_TYPE_DEDICATED | A dedicated server process is being used with the connection. |
DPI_SERVER_TYPE_POOLED | A pooled server process (DRCP) is being used with the connection. |
DPI_SERVER_TYPE_SHARED | A shared server process is being used with the connection. |
DPI_SERVER_TYPE_UNKNOWN | The type of server process is unknown. |