pub type dpiSubscrNamespace = u32;Expand description
This enumeration identifies the namespaces supported by subscriptions.
| Value | Description |
|---|---|
DPI_SUBSCR_NAMESPACE_AQ | Identifies the namespace used for receiving notifications when messages are available to be dequeued in advanced queueing (AQ). |
DPI_SUBSCR_NAMESPACE_DBCHANGE | Identifies the namespace used for receiving notifications for database object changes and query changes (CQN). |