#[repr(C)]pub union dpiDataBuffer {
Show 22 fields
pub asBoolean: c_int,
pub asUint8: u8,
pub asUint16: u16,
pub asUint32: u32,
pub asInt64: i64,
pub asUint64: u64,
pub asFloat: f32,
pub asDouble: f64,
pub asString: *mut c_char,
pub asRaw: *mut c_void,
pub asBytes: dpiBytes,
pub asTimestamp: dpiTimestamp,
pub asIntervalDS: dpiIntervalDS,
pub asIntervalYM: dpiIntervalYM,
pub asJson: *mut dpiJson,
pub asJsonObject: dpiJsonObject,
pub asJsonArray: dpiJsonArray,
pub asLOB: *mut dpiLob,
pub asObject: *mut dpiObject,
pub asStmt: *mut dpiStmt,
pub asRowid: *mut dpiRowid,
pub asVector: *mut dpiVector,
}Expand description
This union is used for passing data to and from the database without requiring casts.
Fields
asBoolean: c_intValue that is used when the native type that is being used is DPI_NATIVE_TYPE_BOOLEAN. The value should be either 1 (true) or 0 (false).
asUint8: u8Only used for getting/setting OCI attributes of 1 byte in length.
asUint16: u16Only used for getting/setting OCI attributes of 2 bytes in length.
asUint32: u32Only used for getting/setting OCI attributes of 4 bytes in length.
asInt64: i64Value that is used when the native type that is being used is DPI_NATIVE_TYPE_INT64.
asUint64: u64Value that is used when the native type that is being used is DPI_NATIVE_TYPE_UINT64.
asFloat: f32Value that is used when the native type that is being used is DPI_NATIVE_TYPE_FLOAT.
asDouble: f64Value that is used when the native type that is being used is DPI_NATIVE_TYPE_DOUBLE.
asString: *mut c_charOnly used for getting/setting OCI attributes of type string.
asRaw: *mut c_voidRaw pointer used for getting/setting all OCI attributes.
asBytes: dpiBytesValue that is used when the native type that is being used is
DPI_NATIVE_TYPE_BYTES. This is a structure of type
dpiBytes.
asTimestamp: dpiTimestampValue that is used when the native type that is being used is
DPI_NATIVE_TYPE_TIMESTAMP. This is a structure of type
dpiTimestamp.
asIntervalDS: dpiIntervalDSValue that is used when the native type that is being used is
DPI_NATIVE_TYPE_INTERVAL_DS. This is a structure of type
dpiIntervalDS.
asIntervalYM: dpiIntervalYMValue that is used when the native type that is being used is
DPI_NATIVE_TYPE_INTERVAL_YM. This is a structure of type
dpiIntervalYM.
asJson: *mut dpiJsonValue that is used when the native type that is being used is DPI_NATIVE_TYPE_JSON. This is a reference to a JSON value which can be used for reading and writing the data that belongs to it.
asJsonObject: dpiJsonObjectValue this is used when the native type that is being used is
DPI_NATIVE_TYPE_JSON_OBJECT. This is a structure of type
dpiJsonObject.
asJsonArray: dpiJsonArrayValue this is used when the native type that is being used is
DPI_NATIVE_TYPE_JSON_ARRAY. This is a structure of type
dpiJsonArray.
asLOB: *mut dpiLobValue that is used when the native type that is being used is DPI_NATIVE_TYPE_LOB. This is a reference to a LOB (large object) which can be used for reading and writing the data that belongs to it.
asObject: *mut dpiObjectValue that is used when the native type that is being used is DPI_NATIVE_TYPE_OBJECT. This is a reference to an object which can be used for reading and writing its attributes or element values.
asStmt: *mut dpiStmtValue that is used when the native type that is being used is DPI_NATIVE_TYPE_STMT. This is a reference to a statement which can be used to query data from the database.
asRowid: *mut dpiRowidValue that is used when the native type that is being used is DPI_NATIVE_TYPE_ROWID. This is a reference to a rowid which is used to uniquely identify a row in a table in the database.
asVector: *mut dpiVectorValue that is used when the native type that is being used is DPI_NATIVE_TYPE_VECTOR. This is a reference to a vector value which can be used for reading and writing the data that belongs to it.